@@ -55,14 +55,14 @@ function help() {
 	exit 2
 }
 
-args=$(getopt -q -o dwmh -l database,web,managementnode,help,dbhost:,dbname:,dbadminuser:,dbadminpass:,rc: -n $0 -- "$@")
+args=$(getopt -q -o dwmh -l database,web,managementnode,help,dbhost:,dbname:,dbadminuser:,dbadminpass: -n $0 -- "$@")
 
 if [ $? -ne 0 ]; then help; fi
 
 eval set -- "$args"
 
 # ------------------------- variables -------------------------------
-VCL_VERSION=2.5.1
+VCL_VERSION=2.5.2
 OLD_VERSION=""
 DB_NAME=vcl
 WEB_PATH=/var/www/html/vcl
@@ -72,7 +72,7 @@ DB_ADMINPASS=""
 
 DB_HOST=localhost
 ARCHIVE=apache-VCL-$VCL_VERSION.tar.bz2
-ARCHIVEURLPATH="http://vcl.apache.org/downloads/download.cgi?action=download&filename=%2Fvcl%2F$VCL_VERSION%2F"
+DOWNLOADARCHIVEURL="http://www.apache.org/dyn/closer.lua/vcl/$VCL_VERSION/$ARCHIVE?action=download"
 SIGPATH="https://www.apache.org/dist/vcl/$VCL_VERSION/"
 
 DODB=0
@@ -83,7 +83,6 @@ dbhostdefault=1
 dbnamedefault=1
 dbadminuserdefault=1
 dbadminpassdefault=1
-dorc=0
 
 while true; do
 	case "$1" in
@@ -122,11 +121,6 @@ while true; do
 			dbadminpassdefault=0
 			shift 2
 			;;
-		--rc)
-			RC=$2
-		   dorc=1
-			shift 2
-			;;
 		-h|--help)
 			help
 			exit 1
@@ -142,19 +136,6 @@ while true; do
 	esac
 done
 
-if [[ $dorc -eq 1 ]]; then
-	if [[ ! $RC =~ ^[0-9]+$ ]]; then
-		echo ""
-		echo "Invalid value specified for --rc=, must be a number"
-		echo ""
-		exit 1
-	fi
-	VCL_VERSION=${VCL_VERSION}-RC$RC
-	ARCHIVE=apache-VCL-$VCL_VERSION.tar.bz2
-	ARCHIVEURLPATH="https://people.apache.org/~jfthomps/apache-VCL-${VCL_VERSION}/"
-	SIGPATH="https://people.apache.org/~jfthomps/apache-VCL-${VCL_VERSION}/"
-fi
-
 if [[ $DOALL -eq 1 ]]; then
 	DODB=1
 	DOWEB=1
@@ -296,8 +277,8 @@ if [ $? -ne 0 ]; then echo "Error: Failed to install required linux package (wge
 # ------------------------------------ functions -------------------------------
 
 function download_archive() {
-	wget -q "$ARCHIVEURLPATH$ARCHIVE" -O $ARCHIVE
-	if [ $? -ne 0 ]; then generic_error "failed to download $ARCHIVE from $ARCHIVEURLPATH"; exit 1; fi
+	wget -q "$DOWNLOADARCHIVEURL" -O $ARCHIVE
+	if [ $? -ne 0 ]; then generic_error "failed to download from $DOWNLOADARCHIVEURL"; exit 1; fi
 }
 
 function validate_archive_sha512() {
